@@ -2,8 +2,8 @@ package My::Test;
 use strict;
 use warnings;
 
-our $VERSION = "0.0.1";
-use 5.008;
+our $VERSION = "0.2.5";
+#use 5.008;
 
 =head1 NAME
 
